/*******************************************************************/
/*

Demo-Software for smart cameras from Vision Components
------------------------------------------------------

Program: Klaus Schneider,  VC


Program Description:
--------------------

This program is an example, how you can store jpeg images
in the flash eprom and read it back in order to display
it on the monitor.

*/
/*******************************************************************/

#include <vcrt.h>
#include <vclib.h>
#include <macros.h>
#include <sysvar.h>

/*******************************************************************/

void main()
{
  char name[]="fd:/jpegfile.jpg"; /* store image in Flash */
  int err, x, y, dx, dy;
  FILE *fp;
  image Img, Ovl;


  /* define area in the center of the screen */
  dx = 128;
  dy = 128;
  x  = (ScrGetColumns-dx)/2;
  y  = (ScrGetRows   -dy)/2;


  /* Set logical page */
  ScrSetLogPage((int)ScrGetPhysPage);
  OvlSetLogPage((int)OvlGetPhysPage);


  /* area size for jpeg should be in steps of 8 , position should be an even point */
  ImageAssign(&Img,ScrByteAddr((x/2)*2,(y/2)*2),(dx/8)*8,(dy/8)*8,ScrGetPitch);
  ImageAssign(&Ovl,OvlByteAddr((x/2)*2,(y/2)*2),(dx/8)*8,(dy/8)*8,OvlGetPitch);


  /* clear overlay */
  OvlClearAll;

  /* Overlay on */
  set_ovlmask(255);

  /* Draw a rectangle */
  frameo(&Ovl);
  vmode(vmOvlLive);  


  pstr("Take Picture and Store Image (press any key)\n");
  rs232rcv();
  tpict();


  /* delete old file if it exist */
  /*******************************/
  fp = io_fopen(name,"c");
  if(fp)
    {
    print("delete old file %s\n",name);
    io_ioctl(fp, IO_DEL);
    io_fclose(fp);
    }
  else
    {
    print("no old file to delete\n");
    }


  /* write file to flash */
  /***********************/
  err = fwrite_jpeg(&Img,name,50,(int)fremain());



  print("Delete Image (press any key)\n");
  rs232rcv();
  set(&Img,0);

  print("Restore the picture from the file (press any key)\n");
  rs232rcv();

  err = fread_jpeg(&Img,name);
  if (err!=0) pstr("\njpeg error!\n");
}

/*******************************************************************/

